@@ -54,10 +54,7 @@ bool global_demo_mode  = false;
 int main(int argc, char *argv[])
 {
     global_debug = 0;
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
+
     QApplication application(argc, argv);
     KLocalizedString::setApplicationDomain("lskat");
 
@@ -76,13 +73,13 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Benjamin Meyer"), i18n("Code Improvements"));
     // 'Thanks to' aboutData.addCredit(i18n("KDE"), i18n("KDE"));
 
-    QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("lskat")));
 
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("d") << QStringLiteral("debug"), i18n("Enter debug level"), QStringLiteral("level")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("skipintro"), i18n("Skip intro animation")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("demo"), i18n("Run game in demo (autoplay) mode")));
-
+    QCommandLineParser parser;
+    parser.addOption(QCommandLineOption({QStringLiteral("d"), QStringLiteral("debug")}, i18n("Enter debug level"), QStringLiteral("level")));
+    parser.addOption(QCommandLineOption({QStringLiteral("skipintro")}, i18n("Skip intro animation")));
+    parser.addOption(QCommandLineOption({QStringLiteral("demo")}, i18n("Run game in demo (autoplay) mode")));
     aboutData.setupCommandLine(&parser);
     parser.process(application);
     aboutData.processCommandLine(&parser);
@@ -120,7 +117,5 @@ int main(int argc, char *argv[])
         mainwindow->show();
     }
 
-    application.setWindowIcon(QIcon::fromTheme(QStringLiteral("lskat")));
-
     return application.exec();
 }
